#
# spec file for package xfce4-power-manager
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define panel_version 4.12.0
%bcond_with git
Name:           xfce4-power-manager
Version:        4.18.3
Release:        bp160.1.9
Summary:        Power Management for the Xfce Desktop Environment
License:        GPL-2.0-or-later
Group:          System/GUI/XFCE
URL:            https://docs.xfce.org/xfce/xfce4-power-manager/start
Source0:        https://archive.xfce.org/src/xfce/xfce4-power-manager/4.18/%{name}-%{version}.tar.bz2
Source1:        xfce4-power-manager.xml
BuildRequires:  appstream-glib
BuildRequires:  fdupes
BuildRequires:  intltool
BuildRequires:  libxslt-tools
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(dbus-1)
BuildRequires:  pkgconfig(dbus-glib-1)
BuildRequires:  pkgconfig(gio-2.0) >= 2.66
BuildRequires:  pkgconfig(gio-unix-2.0) >= 2.66
BuildRequires:  pkgconfig(glib-2.0) >= 2.66
BuildRequires:  pkgconfig(gmodule-2.0) >= 2.66
BuildRequires:  pkgconfig(gobject-2.0) >= 2.66
BuildRequires:  pkgconfig(gthread-2.0) >= 2.66
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.24
BuildRequires:  pkgconfig(libnotify) >= 0.4.1
BuildRequires:  pkgconfig(libxfce4panel-2.0) >= %{panel_version}
BuildRequires:  pkgconfig(libxfce4ui-2) >= 4.18.4
BuildRequires:  pkgconfig(libxfce4util-1.0) >= 4.12.0
BuildRequires:  pkgconfig(libxfconf-0) >= 4.12.0
BuildRequires:  pkgconfig(polkit-gobject-1) >= 0.100
BuildRequires:  pkgconfig(upower-glib) >= 0.99.0
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xext)
BuildRequires:  pkgconfig(xrandr) >= 1.2.0
%if %{with git}
BuildRequires:  xfce4-dev-tools
%endif
Requires:       /usr/bin/pkexec
Requires:       systemd
Requires:       upower
Recommends:     %{name}-lang = %{version}
Provides:       xfce4-power-manager-doc = %{version}
Obsoletes:      xfce4-power-manager-doc <= 1.2.0

%description
The Xfce Power Manager is a tool for the Xfce desktop environment for managing
profiles of policies which affect power consumption, such as the display
brightness level, display sleep times, or CPU frequency scaling. It can also
trigger actions on certain events such as closing the lid or reaching low
battery levels and provides a set of interfaces to inform other applications
about current power level so that they can adjust their power consumption.
Furthermore, it provides a standardized inhibit interface which allows
applications to prevent automatic sleep actions via the power manager.

%package -n xfce4-power-manager-plugin
Summary:        Xfce Panel Plugin for Monitoring Batteries and Changing the Display Brightness
Group:          System/GUI/XFCE
Requires:       %{name} = %{version}
Requires:       xfce4-panel >= %{panel_version}
Provides:       xfce4-panel-plugin-brightness = %{version}
Obsoletes:      xfce4-panel-plugin-brightness <= 1.3.0
Provides:       xfce4-panel-plugin-xfce4battery = %{version}
Obsoletes:      xfce4-panel-plugin-xfce4battery <= 1.3.1
# package was renamed in 2019 after Leap 15.1
Obsoletes:      xfce4-panel-plugin-power-manager < %{version}-%{release}
Provides:       xfce4-panel-plugin-power-manager = %{version}-%{release}

%description -n xfce4-power-manager-plugin
This package provides a plugin for the Xfce panel for monitoring battery and
device charge levels and to regulate display brightness.

%package branding-upstream
Summary:        Upstream Branding of xfce4-power-manager
Group:          System/GUI/XFCE
Supplements:    packageand(%{name}:branding-upstream)
Conflicts:      otherproviders(%{name}-branding)
Provides:       %{name}-branding = %{version}
#BRAND: xfce4-power-manager.xml: Determines power management policy and related
#BRAND: event actions.
BuildArch:      noarch

%description branding-upstream
This package provides the openSUSE look and feel for the Xfce Power Manager.

%lang_package

%prep
%autosetup -p1

# xfce4-pm-helper is only needed on non-systemd systems
xsltproc --nonet - ./src/org.xfce.power.policy.in2 <<'EOF' \
    > ./src/org.xfce.power.policy.in2.new && \
    mv ./src/org.xfce.power.policy.in2.new ./src/org.xfce.power.policy.in2
<?xml version="1.0"?>
<xsl:stylesheet
  version="1.0"
  xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
  <xsl:output
  doctype-public="-//freedesktop//DTD PolicyKit Policy Configuration 1.0//EN"
  doctype-system="http://www.freedesktop.org/standards/PolicyKit/1.0/policyconfig.dtd"/>
  <xsl:template match="action[@id='org.xfce.power.xfce4-pm-helper']" />
  <xsl:template match="@*|node()">
    <xsl:copy>
      <xsl:apply-templates select="@*|node()"/>
    </xsl:copy>
  </xsl:template>
</xsl:stylesheet>
EOF

%build
%if %{with git}
NOCONFIGURE=1 ./autogen.sh
%configure \
    --enable-maintainer-mode
%else
%configure
%endif
%make_build

%install
%make_install

install -D -p -m 644 %{SOURCE1} \
    %{buildroot}%{_sysconfdir}/xdg/xfce4/xfconf/xfce-perchannel-xml/xfce4-power-manager.xml

%suse_update_desktop_file xfce4-power-manager-settings
%suse_update_desktop_file xfce4-power-manager

rm %{buildroot}%{_libdir}/xfce4/panel/plugins/libxfce4powermanager.la

# xfce4-pm-helper is only needed on non-systemd systems
rm %{buildroot}%{_sbindir}/xfce4-pm-helper

%find_lang %{name} %{?no_lang_C}

%fdupes %{buildroot}/%{_datadir}

appstream-util validate-relax --nonet %{buildroot}%{_datadir}/metainfo/*.appdata.xml

%files
%if %{with git}
%doc AUTHORS NEWS README.md
%else
%doc AUTHORS NEWS README.md ChangeLog
%endif
%license COPYING
%{_bindir}/xfce4-power-manager
%{_bindir}/xfce4-power-manager-settings
%{_sbindir}/xfpm-power-backlight-helper
%config %{_sysconfdir}/xdg/autostart/xfce4-power-manager.desktop
%{_mandir}/man1/xfce4-power-manager*.1*
%dir %{_datadir}/polkit-1
%dir %{_datadir}/polkit-1/actions
%{_datadir}/polkit-1/actions/org.xfce.power.policy
%dir %{_datadir}/metainfo
%{_datadir}/metainfo/xfce4-power-manager.appdata.xml
%{_datadir}/applications/xfce4-power-manager-settings.desktop
%{_datadir}/icons/hicolor/*/*/*

%files lang -f %{name}.lang

%files -n xfce4-power-manager-plugin
%{_libdir}/xfce4/panel/plugins/libxfce4powermanager.so
%{_datadir}/xfce4/panel/plugins/power-manager-plugin.desktop

%files branding-upstream
%dir %{_sysconfdir}/xdg/xfce4
%dir %{_sysconfdir}/xdg/xfce4/xfconf
%dir %{_sysconfdir}/xdg/xfce4/xfconf/xfce-perchannel-xml
%config %{_sysconfdir}/xdg/xfce4/xfconf/xfce-perchannel-xml/xfce4-power-manager.xml

%changelog
* Thu Nov 30 2023 Manfred Hollstein <manfred.h@gmx.net>
- Update to version 4.18.3
  * power: Fix inhibition management
  * settings: Present window to the user when already opened
  * settings: Remove useless g_application_hold/release()
  * A review of signal handlers disconnection
  * Remove #ifdefs DEBUG
  * brightness: Rework min level management
  * Refactor XfpmBrightness
  * Remove useless logs
  * backlight: Adjust some spacing for consistency / readability
  * backlight: Return earlier when brightness key event should not be
    handled
  * backlight: fix "handle display brightness keys" setting
  * Simplify brightness level management (Fixes #139)
  * Add missing properties for panel plugin settings
  * Use same debug function everywhere (V2)
  * brightness: Silence more warnings
  * Fix previous commit (again)
  * Fix previous commit
  * Fix g_spawn*_sync() wait status management
  * brightness: Fix g_spawn() wait status management
  * Silence some more warnings
  * Update docs url
  * power: Fix memory leak
  * settings: Fix hidden widgets when !has_lcd_brightness
  * backlight: Fix xfconf warning about cancelled operation
  * Lower some warning levels
  * Use same debug function everywhere
  * Fix upower object management
  * plugin: Fix non unreffed objects on finalize
  * systray-icon: Fix "floating object" warning on finalize
  * systray-icon: Fix "invalid property" warnings
  * Suspend system if lock screen fails on lid close (Fixes #209)
  * Add energy rate into device details
  * power: Fix use of g_hash_table_get_values()
  * Fix light locker integration (Fixes #201)
  * Add app icon at 64px, 96px, clean up SVG metadata
  * Fix description for pending states.
  * Translation Updates
* Tue May 30 2023 Manfred Hollstein <manfred.h@gmx.net>
- Update to version 4.18.2
  * Fix typos in previous backported commit
  * Keep "lock-on-sleep" in sync with other components via XfceScreensaver
  * power: Fix old typo
  * Do not check repeatedly for logind running
  * Write on stderr when appropriate
  * build: Require gio-unix-2.0
  * settings: Keep a ref on device to avoid use-after-free (Fixes #56)
  * dpms: Add missing sanity checks (Fixes #163)
  * Fix Xfconf memory management
  * Update bug report address
  * Translation Updates
* Fri Feb 10 2023 Manfred Hollstein <manfred.h@gmx.net>
- Update to version 4.18.1
  * Update copyright year
  * Use XfceScreensaver from Libxfce4ui (!33)
  * screensaver: Fall back on lock command if D-Bus call failed (#142, !24)
  * panel-plugin: Properly disconnect signal handler
  * build: Fix autotools warnings
  * Fix management of source ids
  * panel-plugin: Add missing ref on image
  * Fix blurriness in icons when UI scale factor > 1 (!30)
  * Translation Updates
* Thu Dec 22 2022 Manfred Hollstein <manfred.h@gmx.net>
- Update to version 4.18.0
  * Bump requirements for Xfce 4.18
  * Translation Updates
- Remove inhibit_dpms.patch
- Update to version 4.17.1
  * Bump copyright year to 2022
  * Do not include `config.h` in headers
  * autoconf: Use AC_CONFIG_MACRO_DIRS
- Update to version 4.17.0
  * Allocate dynamic memory to `what` so that it can be `g_free`d later
  * Connect to polkit signal via GDBusProxy generic signal
  * Do not log a warning about expected behavior
  * Fix compilation warnings
  * Fix icon name in autostart launcher
  * Fix intltool lock file bug in make distcheck
  * Fix memory corruption due to incorrect g_ptr_array usage
  * Fix memory leak and make `while` more efficient
  * Fix missing-prototypes
  * Fix va_args usage in get_device_icon_name
  * Free `eggalarm` after its last use
  * Increase sleep timeout to 6hrs (gxo#xfce/xfce4-settings#80)
  * Inhibit DPMS when getting power inhibit request.
  * Lower minimum inactivity to 5 minutes
  * Remove GSourceFunc casts
  * Remove a floating reference
  * Revert "Lower minimum inactivity to 5 minutes"
  * Translation Updates
  * automake: Enable subdir-objects
  * backlight: always update notification
  * panel-plugin: Switch percentage and time
  * remove unused variable show_presentation_indicator
  * settings: Revert type hint change
* Mon Aug  8 2022 Marcel Kuehlhorn <tux93@opensuse.org>
- Add requirement to pkexec for brightness control (boo#1202125)
* Mon Jan  3 2022 Predrag Ivanović <predivan@mts.rs>
- Add inhibit_dpms.patch
  Inhibit DPMS when getting power inhibit request.
    (gxo#xfce/xfce4-power-manager!22)
* Wed Dec 23 2020 Maurizio Galli <maurizio.galli@gmail.com>
- Update to version 4.16.0
  * bump glib (and gio, gthread, etc) minimum to 2.50.0
  * panel-plugin: Prefer ac-adapter-symbolic
    (Fixes gxo#xfce/xfce4-settings#103)
  * Add new icons in size 24x24 and 32x32
  * Translation Updates
* Sat Nov  7 2020 Maurizio Galli <maurizio.galli@gmail.com>
- Update to version 1.7.1
  * Add new app icon and switch to rDNS icon name
  * Use more accurate status icons (gxo#xfce/xfce4-settings#95)
  * Also use symbolic icons in battery notifications
  * Reorder screensavers so Xfce comes first (gxo#xfce/xfce4-settings#101)
  * settings: Adjust title and show min/max buttons
  * settings: Allow critical battery level up to 70%% (gxo#xfce/xfce4-settings#67)
  * settings: Add keywords for discoverability (bxo#10694)
  * settings: Fix GtkSwitch signal handlers (gxo#xfce/xfce4-settings#99)
  * xfpm: avoid default double fork
  * Respect the notification daemon's timeouts (gxo#xfce/xfce4-settings#57)
  * Fix Laptop lid settings (bxo#15300)
  * Fix spelling mistake (bxo#16698)
  * Only update blank time when appropriate
  * Bug #16717: Move from exo-csource to xdt-csource
  * Guard against NULL pointer dereference
  * More blank time debug code
  * Indentation fixe
  * Cleanup code
  * Move default icon names into one place
  * Silence compiler warnings
  * Add README.md
  * Add basic GitLab pipeline
  * Translation Updates
* Fri Aug 28 2020 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 1.7.0
  * Fix inhibiting xfce4-screensaver (bxo#16364)
  * Fix indentation (makes git blame harder, but code more readable)
  * settings: Unclutter system and display tabs
  * settings: Move %% sign out of spinbutton (bxo#15994)
  * Switch to symbolic window-close icons
  * Dismiss critical notification when connecting to AC
  * Make brightness steps configurable (bxo#12062)
  * Allow compilation with panel 4.15
  * panel-plugin: Properly show 'About' menu item
  * panel-plugin: Add (optional) Presentation mode indicator (bxo#15773)
  * panel-plugin: Toggle presentation mode on middle click
  * panel-plugin: Add warning color to presentation mode indicator
  * panel-plugin: Use GtkSwitch for Presentation mode
  * panel-plugin: Replace deprecated call
  * systray: Ensure presentation mode can be toggled (bxo#16337)
  * Translation Updates
* Mon Mar  9 2020 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 1.6.6
  * Dismiss critical notification when connecting to AC
  * Fix inhibiting xfce4-screensaver (bxo#16364)
  * settings: Move %% sign out of spinbutton (bxo#15994)
  * panel-plugin: Toggle presentation mode on middle click
  * panel-plugin: Properly show 'About' menu item
  * panel-plugin: Add missing about callback
  * panel-plugin: Properly hook up about signal
  * panel-plugin: Replace deprecated call
  * Switch to symbolic window-close icons
* Fri Aug 16 2019 Maurizio Galli <maurizio.galli@gmail.com>
- Fixed sources in spec file
* Mon Aug 12 2019 Maurizio Galli <maurizio.galli@gmail.com>
- Update to version 1.6.5
  * Improve size of critical power level spin
  * Correctly hide brightness label (bxo#14649)
  * Replace GtkStock buttons
  * Add icons to close and help buttons in prefs
  * Translation Updates
- Cleaned up spec file
* Sun Jul 28 2019 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 1.6.4
  * Make inhibition affect dimming and inactivity action (bxo#14687)
  * Add support of xfce4-screensaver
  * Disable trayicon when panel plugin is present (bxo#15682)
  * Translation updates
* Wed Jul 17 2019 Maurizio Galli <maurizio.galli@gmail.com>
- Panel plugin sub-package renamed to follow upstream name:
  xfce4-foo-plugin
* Sun Jun 30 2019 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 1.6.3
  * Revert "Read from actual_brightness instead of brightness"
  * Translation updates
- Validate appstream metadata
* Fri May 17 2019 Maurizio Galli <maurizio.galli@gmail.com>
- Update to version 1.6.2
  * Fix compiler warning (bxo#14104)
  * Fix various warnings
  * Don't autostart the power manager in the LXQt DE (bxo#14450)
  * Don't overwrite the user's XScreensaver settings (bxo#14968)
  * Fix slider labels (bxo#14395)
  * Replace xfconf_channel_new by xfconf_channel_get
  * Read from actual_brightness instead of brightness
  * Fix g_type_class_add_private is deprecated
  * Handle glib deprecations
  * Use the newer up_client_get_devices2
  * Install Appdata in metainfo (bxo#15380)
  * plugin: Show discharge level even in unknown state (bxo#15280)
  * settings: change "going from sleep" to "going to sleep"(bxo#15144)
  * settings: Improve devices tab visually by adding frame
  * Translation updates
- Dropped obsolete patches:
  - xfce4-power-manager-1.6.1-fix-no-return-in-nonvoid.diff
  - xfce4-power-manager-1.6.1-no-show-in-lxqt.diff
- Added bcond to build with sources from git master branch
- Switched to %%autosetup for simpler maintenance
- Switch urls to https://
- Cleaned up spec file
* Tue May 15 2018 seife+obs@b1-systems.com
- add xfce4-power-manager-1.6.1-no-show-in-lxqt.diff (boo#1092247)
* Tue Dec 19 2017 seife+obs@b1-systems.com
- update to version 1.6.1:
  New stable release of xfce4-power-manager.
  - plugin:
  - Use libxfce4panel function to obtain desired icon size
  - Fix menu leak, attach menu to button (bxo#13466)
  - Hide label in unknown state (bxo#12851)
  - Add properties dialog (bxo#13270)
  - Set ac-adapter icon for desktop systems (bxo#13959)
  - Hide label by default on desktop systems
  - Block panel autohide if the menu is open
  - Drop deprecated CSS styles
  - Fix xfpm startup dialog ignoring response (bxo#13700)
  - Fix handling of dialog responses for suspend and hibernate
    (bxo#13405)
  - Set the transient hint for notifications
  - Fix scale description and values for light-locker (bxo#13303)
  - Drop period at end of all tooltip texts (bxo#12342)
  - Make tooltip more concise (bxo#12342)
  - When locking fallback to xflock4 first (bxo#12603)
  - Fix a crash when warning about the screenlocker (bxo#12603)
  - Fix showing inhibits in the systray (bxo#12605)
  - Fix the g_object_bindings in xfce-screensaver
  - Handle screensaver activity with it's own class (bxo#12603)
  - Fix GTK 3.20 deprecation warnings
  - Use the kernel-supplied backlight type rather than a whitelist
    (bxo#12553)
  - Add MATE to NotShowIn list (bxo#12506)
  - Translation updates
- add xfce4-power-manager-1.6.1-fix-no-return-in-nonvoid.diff
  (bxo#14104)
* Sat Nov 26 2016 seife+obs@b1-systems.com
- update to version 1.6.0
  - port to GTK3
  - port to gdbus
  - drop LXDE panel plugin
  - screensaver fixes / improvements
  - various crash fixes
  - memory leaks fixed
  - many other improvements, see ChangeLog and NEWS file
* Sun Mar 22 2015 gber@opensuse.org
- update to version 1.4.4
  - Re-introduce the trayicon for better support of other DEs
    (bxo#11054)
  - Miscellaneous bug fixes:
  - Fix dbus call for CK2 suspend (bxo#11610)
  - Function check_for_consolekit2 is not used if
    !UP_CHECK_VERSION(0, 99, 0) (bxo#11657)
  - Fix xfpm panel plugin crashes at startup when the locale is
    not UTF8
  - The scalemenuitem is actually an imagemenuitem
  - Translation updates
* Sat Feb 28 2015 gber@opensuse.org
- update to version 1.4.3
  - Miscellaneous bug fixes:
  - Handle autotools m4 stuff properly
  - Plug a memory leak (bxo#11538)
  - Add support for ConsoleKit2
  - Correctly check for hibernation permissions (bxo#11529)
  - Use sysctl(3) to get or set brightness level on FreeBSD and
    DragonFly systems
  - Light Locker Integration (bxo#11488)
  - Add gmux_backlight as supported interface (bxo#11406)
  - Reformat code in xfpm_power_get_property
  - Reformat code in xfpm_power_set_property
  - Translation updates:
* Mon Dec  1 2014 gber@opensuse.org
- update to version 1.4.2
  - shorten label for system inactivity time (bug #11129)
  - initially disable DPMS widgets when not handling DPMS
  - use translated device type for unknown devices (bug #11217)
  - fix for critical battery action (bxo#11237)
  - add symlinks for UPS-charged icon (Debian bxo#762500)
  - xrandr brightness: Check for eDP devices too (bug #11308)
  - translation updates
- dropped obsolete
  xfce4-power-manager-fix-critical-battery-action.patch
* Mon Oct 27 2014 gber@opensuse.org
- add xfce4-power-manager-fix-critical-battery-action.patch in
  order to fix the broken critical battery action (bxo#11237,
  backported from upstream git)
* Fri Sep 26 2014 gber@opensuse.org
- update to version 1.4.1
  - fix for panel icon not always updating depending on the
    version of UPower in use.
  - fix handle lid switch with loginD (Bug 11160) Fixed by Simon P.
  - translation updates
- remove obsolete xfce4-power-manager-fix-lid-switch-logic.patch
* Tue Sep 16 2014 gber@opensuse.org
- add xfce4-power-manager-fix-lid-switch-logic.patch in order to
  fix the logic of the lid switch handling setting (backported from
  upstream git)
* Mon Sep 15 2014 gber@opensuse.org
- update to version 1.4.0
  - conditionally use xfce_dialog_show_help_with_version
  - add support for lxpanel 0.7+
  - Yves-Alexis Perez fixed the logic of xfconf logind inhibition
  keys
  - plugin: update desktop file install location
  - plugin: Fix crash when devices (dis)connect
  - point to versioned help docs
  - add DragonflyBSD to host check
  - only use batteries for current charge state that are
  used for power supply
  - fix minor build warnings
  - sync the brightness slider with blank and DPMS settings
  - plugin: Use the brightness-slider-min-level for the scroll
  wheel
  - draw a bubble with a question mark if the device state is
  unknown
  - keep blank and DPMS timeout settings in order
  - fix typos in debug messages
  - update AppData info about the panel plugins
  - never try to display the -missing icons
  - add timestamp for 1.3.2 release to AppData
  - add trailing colons in labels for Comboboxes and Spinbuttons
  - translation updates
- drop obsolete xfce4-power-manager-lxpanel-0.7-support.patch
- remove dependency on udisks since udisks support has been removed
* Mon Sep  8 2014 gber@opensuse.org
- add xfce4-power-manager-lxpanel-0.7-support.patch which adds
  support for lxpanel >= 0.7 (bxo#11108)
* Mon Aug 25 2014 gber@opensuse.org
- disable lxpanel-plugin-power-manager which does not build due to
  API changes lxpanel >= 0.7.0 (bxo#11108)
* Thu Aug 21 2014 gber@opensuse.org
- update to latest development version 1.3.2
  - renamed panel plugin from "Battery Indicator Plugin" to "Power
    Manager Plugin" which is more fitting as it doesn't merely show
    the battery status
  - xfce4-power-manager does not rely on special device icons
    anymore for the load status which is now drawn on the standard
    icons
  - fix crash with slider on 32bit systems (bxo#11076)
  - fix version number output on the commandline
  - remove unused code
  - add dedicated icons for the keyboard brightness notifications
  - various icon improvements
  - reorder parts of the settings dialog
  - translation updates
- renamed subpackage xfce4-panel-plugin-xfce4battery to
  xfce4-panel-plugin-power-manager and lxpanel-plugin-lxdebattery
  to lxpanel-plugin-power-manager following upstream
* Mon Aug 11 2014 gber@opensuse.org
- update to latest development version 1.3.1
  - fix settings dialog compatibility with UPower 0.99
  - improvements to the power manager settings dialog
  - new LXDE battery plugin
  - the brightness plugin has been merged into the battery
    indicator plugin
  - the disk spin down feature was removed
  - Simon P fixed a memory corruption crash
  - OnlyShowIn was changed to a NotShowIn for the .desktop files
  - selecting a device in the plugin brings up the details in the
    settings dialog
  - improve strings in devices tab and add percentage
  - fork before gtk/dbus init
  - Andrzej Added support for multi-row panel layouts for the plugin
  - restore screen power after sleep
  - Samuli Suominen fixed suspend/hibernate with UPower 0.9.23
  - Carl Simonson added a notification popup when changing keyboard
    brightness
  - minumum UPower requirement was lowere to 0.9.7 to support
    FreeBSD
  - devices tab flickers on update
  - improve lid-action strings
  - Carl Simonson added a reasonable step value for keyboard
    brightness
  - let xfpm control X11's screensaver extension
  - translation updates
* Mon Jun  2 2014 gber@opensuse.org
- update to latest development version 1.3.0
  - trayicon replaced by new panel plugin to monitor battery and
    device charge levels
  - restructured settings dialog, embedded xfce4-power-information
  - new icons
  - translation updates
- add xfce4-panel-plugin-xfce4-power-manager-battery subpackage for
  the new panel plugin
* Fri Apr 25 2014 gber@opensuse.org
- update to current git snapshot 1.2.0+git199 (revision gaf126a4)
  - see http://git.xfce.org/xfce/xfce4-power-manager/log/ for a
    list of changes
- drop patches that have been included upstream:
  xfce4-power-manager-automake-1.13.patch,
  xfce4-power-manager-fix-battery-icon-typo.patch,
  xfce4-power-manager-fix-brightness-type.patch,
  xfce4-power-manager-fix-broken-translations.patch,
  xfce4-power-manager-fix-help.patch,
  xfce4-power-manager-systemd-inhibit.patch,
  xfce4-power-manager-systemd-shutdown-reboot-support.patch,
  xfce4-power-manager-systemd-suspend-hibernate-suport.patch,
  xfce4-power-manager-upower-0.99.patch
- remove support for openSUSE < 12.3
* Sat Apr 12 2014 seife+obs@b1-systems.com
- add xfce4-power-manager-upower-0.99.patch to make xfpm work with
  upower >= 0.99 again (bnc#873326)
* Tue Oct 29 2013 gber@opensuse.org
- add xfce4-power-manager-branding-upstream subpackage
* Wed Oct 23 2013 gber@opensuse.org
- fix xfce4-power-manager-systemd-suspend-hibernate-suport.patch so
  that it handles cases where CanSuspend/CanHibernate returns
  "challenge", this is consitent behavior with xfce4-session
* Fri Oct 18 2013 gber@opensuse.org
- add xfce4-power-manager-fix-battery-icon-typo.patch in order to
  fix a typo in battery icon name (bxo#8188, bnc#846485)
* Tue Aug  6 2013 gber@opensuse.org
- add xfce4-power-manager-fix-brightness-type.patch in order to use
  the correct type for prightness property and to fix the screen
  auto-dimming issue and brightness panel plugin issue (backported
  from upstream git)
- add xfce4-power-manager-systemd-shutdown-reboot-support.patch in
  order to add systemd shutdown/reboot support (bxo#10167)
- add xfce4-power-manager-systemd-suspend-hibernate-suport.patch in
  order to add systemd suspend/hibernate support (bxo#9963)
- explicitly depend on udisks, upower, and polkit which are used
  via DBus
* Wed Mar 13 2013 pgajdos@suse.cz
- builds with automake 1.13
  * automake-1.13.patch
* Tue Feb 26 2013 gber@opensuse.org
- added xfce4-power-manager-systemd-inhibit.patch which adds
  systemd inhibit support (bnc#789057)
* Thu Nov 15 2012 gber@opensuse.org
- added xfce4-power-manager-fix-broken-translations.patch which
  fixes broken format strings in translations causing crashes
  (bnc#788361)
* Fri Sep 28 2012 gber@opensuse.org
- explicitly depend on ConsoleKit-x11 which is used via DBus
* Mon May  7 2012 gber@opensuse.org
- removed xfce4-power-manager-1.0.10-use-docdir.patch and
  added xfce4-power-manager-fix-help.patch in order to use
  xfce_dialog_show_help() instead of calling xfhelp4 and to remove
  the bundled documentation (bxo#8846)
* Sun Apr 29 2012 gber@opensuse.org
- update to version 1.2.0
  - fix compilation without dpms
  - fix incorrect dialog message and error
  - plug memory leak
  - use valid printf string
  - translation updates
* Sat Apr 14 2012 gber@opensuse.org
- update to version 1.1.0
  - show dialog in settings category
  - store brightness properties as uint
  - put traps around X functions
  - prevent idle being called on removed battery
  - fix brightness not working with numlock on
  - translation updates
- dropped obsolete
  xfce4-power-manager-fix-brightness-key-modifiers.patch,
  xfce4-power-manager-1.0.10-fix-saving-brightness-levels.patch,
  xfce4-power-manager-workaround-xrandr-error.patch,
  xfce4-power-manager-fix-battery-removal.patch
- edit desktop file instead of using
  xfce4-power-manager-0.9.98-lxde-support.patch
* Fri Mar 30 2012 gber@opensuse.org
- update to version 1.0.11
  - don't attach to the status icon if libnotify >= 0.7
  - fix default spin down toggle value
  - support NetworkManager 0.9
  - fix libnotify detection of
    notify_notification_attach_to_status_icon
  - fix broken empty battery icon
  - change backlight property type to long
  - only dim brightness if the current level is brighter
  - refresh adaptor icon when battery device removed
  - optimize icons
  - translation updates
- dropped obsolete
  xfce4-power-manager-1.0.10-fix-libnotify-0.7.patch,
  xfce4-power-manager-1.0.10-support-networkmanager-0.9.patch,
  xfce4-power-manager-1.0.10-fix-broken-icon.patch
- specfile cleanup
- correct dependencies
- split off -lang and -doc subpackages
* Mon Feb 20 2012 gber@opensuse.org
- add missing build dependency on libXrandr-devel
* Mon Oct 24 2011 gber@opensuse.org
- added xfce4-power-manager-workaround-xrandr-error.patch which
  handles X errors when setting brightness via XRANDR gracefully
  rather than crashing (bnc#718980)
- added xfce4-power-manager-fix-battery-removal.patch in order to
  prevent crashes due to xfpm_battery_notify_idle() being called on
  a battery that has been removed (bnc#707127)
* Thu Oct 20 2011 gber@opensuse.org
- added xfce4-power-manager-use-docdir.patch in order to use docdir
  correctly
- install HTML documentation
  into /usr/share/xfce4/xfce4-power-manager/html
* Thu Oct 20 2011 gber@opensuse.org
- xfpm-power-backlight-helper should be in the main package since
  it can be used by xfce4-power-manager itself too
* Mon Oct 10 2011 gber@opensuse.org
- added
  xfce4-power-manager-1.0.10-fix-saving-brightness-levels.patch
  which fixes the type of saved brightness levels so they can be
  correctly loaded again
* Mon Jul 25 2011 andrea.turrini@gmail.com
- Fixed typos in xfce4-power-manager.spec
* Wed Jun 29 2011 gber@opensuse.org
- added xfce4-power-manager-1.0.10-fix-broken-icon.patch which
  fixes the pbroken empty battery icon in the tray
- added xfce4-power-manager-1.0.10-support-networkmanager-0.9.patch
  which adds support fro NetworkManager 0.9
* Wed May  4 2011 gber@opensuse.org
- added xfce4-power-manager-1.0.10-fix-libnotify-0.7.patch in order
  to fix the libnotify 0.7.0 API usage
* Sat Apr  2 2011 gber@opensuse.org
- update to version 1.0.10
  - improved battery notifications and added empty battery
    notification
  - compatibility with libnotify 0.7
  - added configuration for tuning brightness level on AC and on
    battery power
  - translation updates
  - bugfixes
* Fri Feb 18 2011 gber@opensuse.org
- call %%desktop_database_post/un
- call %%icon_theme_cache_post/un
- simplified filelist
* Fri Jan 21 2011 gber@opensuse.org
- improve filelist
* Mon Jan 17 2011 gber@opensuse.org
- add missing directories
* Mon Jan 17 2011 andrea@opensuse.org
- new upstream version 1.0.3
  * bugfixed : no detailed changelog provided
* Tue Jan 11 2011 gber@opensuse.org
- removed dependency on xfconf
* Mon Dec 27 2010 gber@opensuse.org
- use %%%%suse_update_desktop_file for files in /etc/xdg/autostart
* Mon Dec 27 2010 gber@opensuse.org
- suggest xfce4-panel-plugin-brightness
* Mon Dec 27 2010 gber@opensuse.org
- update to version 1.0.2
  * bugfixes
- split off xfce4-panel-plugin-brightness
- mark documentation as such
- improved descriptions/summaries
* Wed Dec 15 2010 prusnak@opensuse.org
- fix filelist
* Wed Dec  1 2010 prusnak@opensuse.org
- use pkgconfig symbol in BuildRequires
* Tue Sep  7 2010 andrea@opensuse.org
- new upstream version 1.0.1
  * no additional changelog provided upstream
* Mon Jul 26 2010 andrea@opensuse.org
- Finally drop HAL bxo#6116
* Thu Jul 22 2010 andrea@opensuse.org
- new upstream version 0.9.98
- rename lxde-support.patch to xfce4-power-manager-0.9.98-lxde-support.patch
- spec file clean up
* Sat Jan 16 2010 andrea@opensuse.org
- added LXDE support to autostart desktop file
* Thu Nov 26 2009 prusnak@suse.cz
- updated to 0.8.4.2
  - Fix inactivity check box not appearing on Desktop system.
  - Fix adapter icon when no battery present (bug #6008).
  - Replace XfpmIdle with EggIdletime from gpm.
  - Reset XScreen saver counter on lid open.
* Wed Nov 11 2009 prusnak@suse.cz
- updated to 0.8.4.1
  - Because on some systems we might not have the brightness keys mapped.
    LCD brightness change are not reflected to xfpm when keys are pressed, so
    save the actual brightness before dimming the screen on idle to restore it
    afterword. (bug #5811).
  - Check if DPMS is enabled before doing action on lid close event (bug #5805).
  - Allow 1%% as a minimum critical charge level.
  - Build fix with xextproto > 7.0.5 (bug #5897).
* Wed Nov 11 2009 prusnak@suse.cz
- updated to 0.8.4
  - Don't lock screen on lid event when multiple monitor are connected.
  - Force DPMSModeOff on lid close event if it is not done in Hardware.
  - Fix a crash in set_client_id (bug #5673).
  - Reduce memory usage on some places.
* Wed Aug 19 2009 prusnak@suse.cz
- added xfce4-panel to Requires
* Wed Aug 12 2009 prusnak@suse.cz
- updated to 0.8.3.1
  - Missing signal handler for power button settings (bug #5656).
  - Allow 5%% as a minimum critical charge instead of 10%%.
  - Change some property names, specially for buttons to avoid
    problems with old 0.6 configuration.
* Wed Aug  5 2009 prusnak@suse.cz
- updated to 0.8.3
  - Provides more standard org.fd.PowerManagement DBus methods and signal (bug #5569).
  - Make it possible to compile without network manager support.
  - Add never show icon to the system tray configuration (bug #5613).
  - Fix a typo that prevents from getting the correct critical configuration (bug #5619).
  - Use Gtk as a popup indicator to show the brightness level as the cairo seems to be
    problematic on some hardware. (bug #5544 #5632).
  - Better alignement in the interface file, worked by Josef Havran.
* Mon Jul 20 2009 dominique-obs@leuenberger.net
- Follow change of %%%%{_libexecdir}
* Tue Jul 14 2009 prusnak@suse.cz
- updated to 0.8.2
* Wed Jun 10 2009 prusnak@suse.cz
- updated to final 0.8.0
- dropped mainlined include.patch
* Mon Apr 27 2009 prusnak@suse.cz
- created package (version 0.7.90.2 aka 0.8.0beta2)
- fix missing includes (include.patch)
